@@ -45,7 +45,7 @@ protected:
     void createCopyImage(int);
 
     // Updates imgBtnPrev# according to imgPath(int)
-    void updateImg(int);
+    void updateImgBtnPrev(int);
 
     void setupFIMenuBar();
 
@@ -68,6 +68,7 @@ protected:
 
     QList<QString*> imgPath;
     QList<QPushButton*> imgBtnPrev;
+    QList<QLabel*> imgPrevName;
 
     // Buttons under imgBtnPrev# (main screen)
     QList<QPushButton*> copyToBtn;
