@@ -5,6 +5,8 @@
 #include "ui_fourimages.h"
 #include "wpmanager.h"
 #include "ui_wpmanager.h"
+#include "aboutdialog.h"
+#include "ui_aboutdialog.h"
 
 #include <QMainWindow>
 #include <QDialog>
@@ -29,22 +31,14 @@ private:
     QMenu* wpMenu;
     QAction* wpMenuActionAbout;
     // The About dialog with its contents
-    bool aboutDialogExists;
-    QDialog* aboutDialog;
-        QLabel* aboutIcon;
-        QLabel* aboutText1;
-        QLabel* aboutText2;
-        QPushButton* aboutOK;
-        QVBoxLayout* aboutLayoutV1;
-        QVBoxLayout* aboutLayoutV2;
-        QVBoxLayout* aboutLayoutV3;
-        QHBoxLayout* aboutLayoutH;
+    bool abtDialogExists;
+    aboutDialog* abtDialog;
 
     fourImages* fourWin;
     wpManager* manWin;
 
 public slots:
-    void createAboutDialog();
+    void createAbtDialog();
     void fourBtnClicked();
     void manBtnClicked();
 };
